@@ -238,3 +238,25 @@ class PythonFormulaeWizard(pwizard.Wizard):
         # If accepted
         if d.resultYes():
             form.setVar('formula',d.getFormula())
+            
+class PythonTopRankWizard(pwizard.Wizard):
+    """Assist in the creation of python formula to be evaluated. In Steps"""
+    _targets = [(emprot.ProtSetFilter, ['rankingField'])]
+
+    def getInputAttributes(self, form):
+        attrNames=[]
+        item = form.protocol.inputSet.get().getFirstItem()
+        for key, attr in item.getAttributesToStore():
+            attrNames.append(key)
+        return attrNames
+
+    def show(self, form, *params):
+        attrsList = self.getInputAttributes(form)
+        finalAttrsList = []
+        for i in attrsList:
+            finalAttrsList.append(pwobj.String(i))
+        provider = ListTreeProviderString(finalAttrsList)
+
+        dlg = dialog.ListDialog(form.root, "Filter set", provider,
+                                "Select one of the attributes")
+        form.setVar('rankingField', dlg.values[0].get())
